functions

package
v0.0.1-alpha Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 29, 2024 License: MIT Imports: 23 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AnalyzeTsharkCapture

func AnalyzeTsharkCapture(captureFile string, analysisDir string) ([]pkg.AnalysisResult, error)

analyze tshark capture and return structured results

func ConfigureNetworkInterfaces

func ConfigureNetworkInterfaces(app *tview.Application, pages *tview.Pages, mainView tview.Primitive) error

func LoadAndApplyNetworkConfig

func LoadAndApplyNetworkConfig(app *tview.Application, pages *tview.Pages, mainView tview.Primitive) error

main function to apply a saved config to the system

func SaveNetworkConfig

func SaveNetworkConfig(app *tview.Application, pages *tview.Pages, mainView tview.Primitive) error

func StartDiscoveryScan

func StartDiscoveryScan(app *tview.Application, pages *tview.Pages, mainView tview.Primitive) error

StartDiscoveryScan initiates the Discovery Scan process with sequential prompts, automatic interface detection, user confirmation, and real-time output display.

func StartWiresharkListening

func StartWiresharkListening(app *tview.Application, pages *tview.Pages, mainView tview.Primitive) error

start wireshark and tshark captures, perform analysis, and update the UI accordingly

func ToggleEthernetInterfaces

func ToggleEthernetInterfaces(app *tview.Application, pages *tview.Pages, mainView tview.Primitive) error

Types

type AnalysisCommand

type AnalysisCommand struct {
	Name string
	Args []string
}

func GetAnalysisCommands

func GetAnalysisCommands(captureFile string) []AnalysisCommand

get tshark analysis commands

Directories

Path Synopsis

Jump to