Documentation
¶
Index ¶
- func AnalyzeTsharkCapture(captureFile string, analysisDir string) ([]pkg.AnalysisResult, error)
- func ConfigureNetworkInterfaces(app *tview.Application, pages *tview.Pages, mainView tview.Primitive) error
- func LoadAndApplyNetworkConfig(app *tview.Application, pages *tview.Pages, mainView tview.Primitive) error
- func SaveNetworkConfig(app *tview.Application, pages *tview.Pages, mainView tview.Primitive) error
- func StartDiscoveryScan(app *tview.Application, pages *tview.Pages, mainView tview.Primitive) error
- func StartWiresharkListening(app *tview.Application, pages *tview.Pages, mainView tview.Primitive) error
- func ToggleEthernetInterfaces(app *tview.Application, pages *tview.Pages, mainView tview.Primitive) error
- type AnalysisCommand
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AnalyzeTsharkCapture ¶
func AnalyzeTsharkCapture(captureFile string, analysisDir string) ([]pkg.AnalysisResult, error)
analyze tshark capture and return structured results
func LoadAndApplyNetworkConfig ¶
func LoadAndApplyNetworkConfig(app *tview.Application, pages *tview.Pages, mainView tview.Primitive) error
main function to apply a saved config to the system
func SaveNetworkConfig ¶
func StartDiscoveryScan ¶
StartDiscoveryScan initiates the Discovery Scan process with sequential prompts, automatic interface detection, user confirmation, and real-time output display.
func StartWiresharkListening ¶
func StartWiresharkListening(app *tview.Application, pages *tview.Pages, mainView tview.Primitive) error
start wireshark and tshark captures, perform analysis, and update the UI accordingly
Types ¶
type AnalysisCommand ¶
func GetAnalysisCommands ¶
func GetAnalysisCommands(captureFile string) []AnalysisCommand
get tshark analysis commands
Source Files
¶
Click to show internal directories.
Click to hide internal directories.